=======
Version
=======

Bumping
=======

This project uses `Semantic Versioning 2.0.0 <https://semver.org/>`_, and
has a bumpversion_ config in ``.bumpversion.cfg``. Thus, remember to run:

* ``bumpversion patch`` to increase version from `0.1.0` to `0.1.1`.
* ``bumpversion minor`` to increase version from `0.1.0` to `0.2.0`.
* ``bumpversion major`` to increase version from `0.1.0` to `1.0.0`.

.. _bumpversion: https://pypi.org/project/bumpversion
